@@ -28,9 +28,12 @@
 #include "ignition/gui/Application.hh"
 #include "ignition/gui/config.hh"
 #include "ignition/gui/Dialog.hh"
+#include "ignition/gui/Helpers.hh"
 #include "ignition/gui/MainWindow.hh"
 #include "ignition/gui/Plugin.hh"
 
+#include "ignition/transport/TopicUtils.hh"
+
 namespace ignition
 {
   namespace gui
@@ -86,11 +89,16 @@ Application::Application(int &_argc, char **_argv, const WindowType _type)
 {
   igndbg << "Initializing application." << std::endl;
 
+  this->setOrganizationName("Ignition");
+  this->setOrganizationDomain("ignitionrobotics.org");
+  this->setApplicationName("Ignition GUI");
+
   // Configure console
   common::Console::SetPrefix("[GUI] ");
 
   // QML engine
   this->dataPtr->engine = new QQmlApplicationEngine();
+  this->dataPtr->engine->addImportPath(qmlQrcImportPath());
 
   // Install signal handler for graceful shutdown
   this->dataPtr->signalHandler.AddCallback(
@@ -269,12 +277,89 @@ bool Application::LoadConfig(const std::string &_config)
     this->dataPtr->windowConfig.MergeFromXML(std::string(printer.CStr()));
 
     // Closing behavior.
+    if (auto defaultExitActionElem =
+      winElem->FirstChildElement("default_exit_action"))
+    {
+      ExitAction action{ExitAction::CLOSE_GUI};
+      const auto value = common::lowercase(defaultExitActionElem->GetText());
+      if (value == "shutdown_server")
+      {
+        action = ExitAction::SHUTDOWN_SERVER;
+      }
+      else if (value != "close_gui" && !value.empty())
+      {
+        ignwarn << "Value '" << value << "' of <default_exit_action> is "
+                << "invalid. Allowed values are CLOSE_GUI and SHUTDOWN_SERVER. "
+                << "Selecting CLOSE_GUI as fallback." << std::endl;
+      }
+      this->dataPtr->mainWin->SetDefaultExitAction(action);
+    }
+
+    // Dialog on exit
     if (auto dialogOnExitElem = winElem->FirstChildElement("dialog_on_exit"))
     {
       bool showDialogOnExit{false};
       dialogOnExitElem->QueryBoolText(&showDialogOnExit);
       this->dataPtr->mainWin->SetShowDialogOnExit(showDialogOnExit);
     }
+
+    if (auto dialogOnExitOptionsElem =
+      winElem->FirstChildElement("dialog_on_exit_options"))
+    {
+      if (auto promptElem =
+        dialogOnExitOptionsElem->FirstChildElement("prompt_text"))
+      {
+        this->dataPtr->mainWin->SetDialogOnExitText(
+          QString::fromStdString(promptElem->GetText()));
+      }
+      if (auto showShutdownElem =
+        dialogOnExitOptionsElem->FirstChildElement("show_shutdown_button"))
+      {
+        bool showShutdownButton{false};
+        showShutdownElem->QueryBoolText(&showShutdownButton);
+        this->dataPtr->mainWin->SetExitDialogShowShutdown(showShutdownButton);
+      }
+      if (auto showCloseGuiElem =
+        dialogOnExitOptionsElem->FirstChildElement("show_close_gui_button"))
+      {
+        bool showCloseGuiButton{false};
+        showCloseGuiElem->QueryBoolText(&showCloseGuiButton);
+        this->dataPtr->mainWin->SetExitDialogShowCloseGui(showCloseGuiButton);
+      }
+      if (auto shutdownTextElem =
+        dialogOnExitOptionsElem->FirstChildElement("shutdown_button_text"))
+      {
+        this->dataPtr->mainWin->SetExitDialogShutdownText(
+          QString::fromStdString(shutdownTextElem->GetText()));
+      }
+      if (auto closeGuiTextElem =
+        dialogOnExitOptionsElem->FirstChildElement("close_gui_button_text"))
+      {
+        this->dataPtr->mainWin->SetExitDialogCloseGuiText(
+          QString::fromStdString(closeGuiTextElem->GetText()));
+      }
+    }
+
+    // Server control service topic
+    std::string serverControlService{"/server_control"};
+    auto serverControlElem =
+      winElem->FirstChildElement("server_control_service");
+    if (nullptr != serverControlElem && nullptr != serverControlElem->GetText())
+    {
+      serverControlService = transport::TopicUtils::AsValidTopic(
+        serverControlElem->GetText());
+    }
+
+    if (serverControlService.empty())
+    {
+      ignerr << "Failed to create valid server control service" << std::endl;
+    }
+    else
+    {
+      ignmsg << "Using server control service [" << serverControlService
+             << "]" << std::endl;
+      this->dataPtr->mainWin->SetServerControlService(serverControlService);
+    }
   }
 
   this->ApplyConfig();
@@ -387,6 +472,9 @@ bool Application::LoadPlugin(const std::string &_filename,
   else
     plugin->Load(_pluginElem);
 
+  if (nullptr == plugin->CardItem())
+    return false;
+
   // Store plugin in queue to be added to the window
   this->dataPtr->pluginsToAdd.push(plugin);
 
