@@ -45,9 +45,9 @@ using namespace std::chrono_literals;
 
 /////////////////////////////////////////////////
 // See https://github.com/ignitionrobotics/ign-gui/issues/75
-TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Constructor))
+TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Constructor))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Constructor
@@ -58,9 +58,9 @@ TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Constructor))
 }
 
 /////////////////////////////////////////////////
-TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(OnSaveConfig))
+TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(OnSaveConfig))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Change default config path
@@ -95,9 +95,9 @@ TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(OnSaveConfig))
 }
 
 /////////////////////////////////////////////////
-TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(SaveConfigAs))
+TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(SaveConfigAs))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   auto mainWindow = new MainWindow;
@@ -131,9 +131,9 @@ TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(SaveConfigAs))
 }
 
 /////////////////////////////////////////////////
-TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(OnLoadConfig))
+TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(OnLoadConfig))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Add test plugins to path
@@ -175,7 +175,7 @@ TEST(MainWindowTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(OnLoadConfig))
 /////////////////////////////////////////////////
 TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(OnAddPlugin))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Add test plugins to path
@@ -207,7 +207,7 @@ TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(OnAddPlugin))
 /////////////////////////////////////////////////
 TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(defaultValues))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
 
   WindowConfig c;
 
@@ -242,7 +242,7 @@ TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(defaultValues))
 /////////////////////////////////////////////////
 TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(mergeFromXML))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
 
   WindowConfig c;
 
@@ -280,7 +280,7 @@ TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(mergeFromXML))
 /////////////////////////////////////////////////
 TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(MenusToString))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
 
   WindowConfig c;
 
@@ -310,7 +310,7 @@ TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(MenusToString))
 /////////////////////////////////////////////////
 TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(IgnoreToString))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
 
   WindowConfig c;
 
@@ -337,7 +337,7 @@ TEST(WindowConfigTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(IgnoreToString))
 TEST(MainWindowTest,
     IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(CloseWithoutSavingChanges))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Access window after it's open
@@ -385,7 +385,7 @@ TEST(MainWindowTest,
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(DefaultExitActionAutoShutdown))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   app.LoadConfig(common::joinPaths(
@@ -398,8 +398,8 @@ TEST(MainWindowTest,
   bool shutdownCalled{false};
   transport::Node node;
   std::string serverControlService{"/server_control"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-  cb = [&](const msgs::ServerControl &_req, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+  cb = [&](const ignition::msgs::ServerControl &_req, msgs::Boolean &_rep) {
     shutdownCalled = _req.stop();
     _rep.set_data(true);
     return true;
@@ -417,7 +417,7 @@ TEST(MainWindowTest,
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ExitActionCustomShutdownService))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   app.LoadConfig(common::joinPaths(
@@ -433,8 +433,8 @@ TEST(MainWindowTest,
   transport::Node node;
 
   std::string serverControlService{"/test_service"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-  cb = [&](const msgs::ServerControl &_req, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+  cb = [&](const ignition::msgs::ServerControl &_req, msgs::Boolean &_rep) {
     shutdownCalled = _req.stop();
     _rep.set_data(true);
     return true;
@@ -442,8 +442,8 @@ TEST(MainWindowTest,
   node.Advertise(serverControlService, cb);
 
   std::string wrongServerControlService{"/server_control"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-  cb2 = [&](const msgs::ServerControl &, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+  cb2 = [&](const ignition::msgs::ServerControl &, msgs::Boolean &_rep) {
     wrongShutdownCalled = true;
     _rep.set_data(true);
     return true;
@@ -462,7 +462,7 @@ TEST(MainWindowTest,
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(DefaultExitActionAutoCloseGui))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Add test plugins to path
@@ -477,8 +477,8 @@ TEST(MainWindowTest,
   bool shutdownCalled{false};
   transport::Node node;
   std::string serverControlService{"/server_control"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-  cb = [&](const msgs::ServerControl &, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+  cb = [&](const ignition::msgs::ServerControl &, msgs::Boolean &_rep) {
     shutdownCalled = true;
     _rep.set_data(true);
     return true;
@@ -562,7 +562,7 @@ void FindExitDialogButtons(
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ExitDialogShutdownButton))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   app.LoadConfig(common::joinPaths(
@@ -594,8 +594,8 @@ TEST(MainWindowTest,
   bool shutdownCalled{false};
   transport::Node node;
   std::string serverControlService{"/server_control"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-    cb = [&](const msgs::ServerControl &, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+    cb = [&](const ignition::msgs::ServerControl &, msgs::Boolean &_rep) {
     shutdownCalled = true;
     _rep.set_data(true);
     return true;
@@ -622,7 +622,7 @@ TEST(MainWindowTest,
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ExitDialogDefaultButtons))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   app.LoadConfig(common::joinPaths(
@@ -653,8 +653,8 @@ TEST(MainWindowTest,
   bool shutdownCalled{false};
   transport::Node node;
   std::string serverControlService{"/server_control"};
-  std::function<bool(const msgs::ServerControl &, msgs::Boolean &)>
-    cb = [&](const msgs::ServerControl &, msgs::Boolean &_rep) {
+  std::function<bool(const ignition::msgs::ServerControl &, msgs::Boolean &)>
+    cb = [&](const ignition::msgs::ServerControl &, msgs::Boolean &_rep) {
     shutdownCalled = true;
     _rep.set_data(true);
     return true;
@@ -670,7 +670,7 @@ TEST(MainWindowTest,
 TEST(MainWindowTest,
      IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ExitDialogButtonsText))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   app.LoadConfig(common::joinPaths(
@@ -711,7 +711,7 @@ TEST(MainWindowTest,
 /////////////////////////////////////////////////
 TEST(MainWindowTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ApplyConfig))
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   Application app(g_argc, g_argv);
 
   // Main window
