@@ -155,14 +155,14 @@ void Grid3D::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
     }
   }
 
-  gui::App()->findChild<
-      MainWindow *>()->installEventFilter(this);
+  ignition::gui::App()->findChild<
+      ignition::gui::MainWindow *>()->installEventFilter(this);
 }
 
 /////////////////////////////////////////////////
 bool Grid3D::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == events::Render::kType)
+  if (_event->type() == ignition::gui::events::Render::kType)
   {
     if (nullptr == this->dataPtr->scene)
       this->dataPtr->scene = rendering::sceneFromFirstRenderEngine();
@@ -418,6 +418,6 @@ void Grid3D::RefreshList()
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(Grid3D,
-                    gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gui::plugins::Grid3D,
+                    ignition::gui::Plugin)
 
