@@ -21,7 +21,6 @@
 
 #include <ignition/common/Console.hh>
 #include <ignition/common/StringUtils.hh>
-#include <ignition/common/Time.hh>
 #include <ignition/plugin/Register.hh>
 
 #include "ignition/gui/Helpers.hh"
@@ -139,6 +138,14 @@ void WorldStats::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
     topic = "/world/" + worldName + "/stats";
   }
 
+  topic = transport::TopicUtils::AsValidTopic(topic);
+  if (topic.empty())
+  {
+    ignerr << "Failed to create valid topic for world [" << worldName << "]"
+           << std::endl;
+    return;
+  }
+
   if (!this->dataPtr->node.Subscribe(topic, &WorldStats::OnWorldStatsMsg,
       this))
   {
@@ -196,22 +203,24 @@ void WorldStats::ProcessMsg()
 {
   std::lock_guard<std::recursive_mutex> lock(this->dataPtr->mutex);
 
-  common::Time time;
+  std::chrono::steady_clock::time_point timePoint;
 
   if (this->dataPtr->msg.has_sim_time())
   {
-    time.sec = this->dataPtr->msg.sim_time().sec();
-    time.nsec = this->dataPtr->msg.sim_time().nsec();
-
-    this->SetSimTime(QString::fromStdString(time.FormattedString()));
+    timePoint = math::secNsecToTimePoint(
+        this->dataPtr->msg.sim_time().sec(),
+        this->dataPtr->msg.sim_time().nsec());
+    this->SetSimTime(QString::fromStdString(
+      math::timePointToString(timePoint)));
   }
 
   if (this->dataPtr->msg.has_real_time())
   {
-    time.sec = this->dataPtr->msg.real_time().sec();
-    time.nsec = this->dataPtr->msg.real_time().nsec();
-
-    this->SetRealTime(QString::fromStdString(time.FormattedString()));
+    timePoint = math::secNsecToTimePoint(
+        this->dataPtr->msg.real_time().sec(),
+        this->dataPtr->msg.real_time().nsec());
+    this->SetRealTime(QString::fromStdString(
+      math::timePointToString(timePoint)));
   }
 
   {
@@ -226,7 +235,7 @@ void WorldStats::ProcessMsg()
 }
 
 /////////////////////////////////////////////////
-void WorldStats::OnWorldStatsMsg(const msgs::WorldStatistics &_msg)
+void WorldStats::OnWorldStatsMsg(const ignition::msgs::WorldStatistics &_msg)
 {
   std::lock_guard<std::recursive_mutex> lock(this->dataPtr->mutex);
 
@@ -287,5 +296,5 @@ void WorldStats::SetIterations(const QString &_iterations)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(WorldStats,
-                    gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gui::plugins::WorldStats,
+                    ignition::gui::Plugin)
